==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QSGBasicGeometryNode_shell.cpp <==
#include "QSGBasicGeometryNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGBasicGeometryNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGBasicGeometryNode")
    QSGBasicGeometryNode *_ptr = reinterpret_cast<QSGBasicGeometryNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGBasicGeometryNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGBasicGeometryNode_shell) ); }

jmethodID QSGBasicGeometryNode_oshell::__shell_javaMethod(int pos) const { return QSGBasicGeometryNode_shell::__shell()->javaMethod(typeid(QSGBasicGeometryNode), pos); }

// emitting (writeShellDestructor)
QSGBasicGeometryNode_shell::~QSGBasicGeometryNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGBasicGeometryNode::~QSGBasicGeometryNode()", this)
    QSGBasicGeometryNode_shell::__shell()->destructed(typeid(QSGBasicGeometryNode));
}

// emitting (writeShellConstructor)
void QSGBasicGeometryNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGBasicGeometryNode_shell*>(ptr)->QSGBasicGeometryNode_shell::__shell()->tryDeleteShell(typeid(QSGBasicGeometryNode));
}

void QSGBasicGeometryNode_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGBasicGeometryNode_oshell*>(ptr)->QSGBasicGeometryNode_oshell::__shell()->tryDeleteShell(typeid(QSGBasicGeometryNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGBasicGeometryNode_oshell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGBasicGeometryNode::isSubtreeBlocked()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGBasicGeometryNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGBasicGeometryNode_shell::__shell()->warnForMethod("QSGBasicGeometryNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGBasicGeometryNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGBasicGeometryNode_oshell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGBasicGeometryNode::preprocess()", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGBasicGeometryNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGBasicGeometryNode_shell::__shell()->warnForMethod("QSGBasicGeometryNode::preprocess()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGBasicGeometryNode::preprocess()");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// destruct QSGBasicGeometryNode_shell
void __qt_destruct_QSGBasicGeometryNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGBasicGeometryNode")
    reinterpret_cast<QSGBasicGeometryNode_shell*>(ptr)->~QSGBasicGeometryNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGBasicGeometryNode::clipList()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_clipList_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::clipList()const", __this_nativeId)
        const QSGClipNode* __qt_return_value = __qt_this->clipList();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::geometry()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_geometry_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::geometry()", __this_nativeId)
        QSGGeometry* __qt_return_value = __qt_this->geometry();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::matrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_matrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::matrix()const", __this_nativeId)
        const QMatrix4x4* __qt_return_value = __qt_this->matrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::setGeometry(QSGGeometry*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setGeometry_1native_1QSGGeometry_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID geometry0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setGeometry(QSGGeometry*)", __this_nativeId)
        QSGGeometry* __qt_geometry0 = QtJambiAPI::objectFromNativeId<QSGGeometry>(geometry0);
        __qt_this->setGeometry(__qt_geometry0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGBasicGeometryNode::setRendererClipList(const QSGClipNode*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setRendererClipList_1native_1const_1QSGClipNode_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID c0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setRendererClipList(const QSGClipNode*)", __this_nativeId)
        const QSGClipNode* __qt_c0 = QtJambiAPI::objectFromNativeId<QSGClipNode>(c0);
        __qt_this->setRendererClipList(__qt_c0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGBasicGeometryNode::setRendererMatrix(const QMatrix4x4*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setRendererMatrix_1native_1const_1QMatrix4x4_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID m0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setRendererMatrix(const QMatrix4x4*)", __this_nativeId)
        const QMatrix4x4* __qt_m0 = QtJambiAPI::objectFromNativeId<QMatrix4x4>(m0);
        __qt_this->setRendererMatrix(__qt_m0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGBasicGeometryNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGBasicGeometryNode>("QSGBasicGeometryNode", "io/qt/quick/QSGBasicGeometryNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGBasicGeometryNode, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGBasicGeometryNode);
    registerSizeOfShell(typeId, sizeof(QSGBasicGeometryNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGBasicGeometryNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.5.8.jar: sources/QtJambiQuick/QSGBasicGeometryNode_shell.cpp <==
#include "QSGBasicGeometryNode_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

void deleter_QSGBasicGeometryNode(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGBasicGeometryNode")
    QSGBasicGeometryNode *_ptr = reinterpret_cast<QSGBasicGeometryNode *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGBasicGeometryNode_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGBasicGeometryNode_shell) ); }

jmethodID QSGBasicGeometryNode_oshell::__shell_javaMethod(int pos) const { return QSGBasicGeometryNode_shell::__shell()->javaMethod(typeid(QSGBasicGeometryNode), pos); }

// emitting (writeShellDestructor)
QSGBasicGeometryNode_shell::~QSGBasicGeometryNode_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGBasicGeometryNode::~QSGBasicGeometryNode()", this)
    QSGBasicGeometryNode_shell::__shell()->destructed(typeid(QSGBasicGeometryNode));
}

// emitting (writeShellConstructor)
void QSGBasicGeometryNode_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGBasicGeometryNode_shell*>(ptr)->QSGBasicGeometryNode_shell::__shell()->tryDeleteShell(typeid(QSGBasicGeometryNode));
}

void QSGBasicGeometryNode_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGBasicGeometryNode_oshell*>(ptr)->QSGBasicGeometryNode_oshell::__shell()->tryDeleteShell(typeid(QSGBasicGeometryNode));
}

// emitting Virtual overrides (virtualFunctions)
bool QSGBasicGeometryNode_oshell::isSubtreeBlocked() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGBasicGeometryNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    QSGBasicGeometryNode_shell::__shell()->warnForMethod("QSGBasicGeometryNode::isSubtreeBlocked()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGBasicGeometryNode::isSubtreeBlocked()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGNode::isSubtreeBlocked();
        }
    }else{
        return QSGNode::isSubtreeBlocked();
    }
}

void QSGBasicGeometryNode_oshell::preprocess()
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        if (JniEnvironmentExceptionHandler __jni_env{200}) {
            QTJAMBI_TRY {
                if(jobject __java_this = QSGBasicGeometryNode_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                } else {
                    QSGBasicGeometryNode_shell::__shell()->warnForMethod("QSGBasicGeometryNode::preprocess()");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QSGBasicGeometryNode::preprocess()");
            } QTJAMBI_TRY_END
        }else{
            QSGNode::preprocess();
        }
    }else{
        QSGNode::preprocess();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// destruct QSGBasicGeometryNode_shell
void __qt_destruct_QSGBasicGeometryNode(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGBasicGeometryNode")
    reinterpret_cast<QSGBasicGeometryNode_shell*>(ptr)->~QSGBasicGeometryNode_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGBasicGeometryNode::clipList()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_clipList_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::clipList()const", __this_nativeId)
        const QSGClipNode* __qt_return_value = __qt_this->clipList();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::geometry()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_geometry_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::geometry()", __this_nativeId)
        QSGGeometry* __qt_return_value = __qt_this->geometry();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::matrix()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_matrix_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::matrix()const", __this_nativeId)
        const QMatrix4x4* __qt_return_value = __qt_this->matrix();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGBasicGeometryNode::setGeometry(QSGGeometry*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setGeometry_1native_1QSGGeometry_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID geometry0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setGeometry(QSGGeometry*)", __this_nativeId)
        QSGGeometry* __qt_geometry0 = QtJambiAPI::objectFromNativeId<QSGGeometry>(geometry0);
        __qt_this->setGeometry(__qt_geometry0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGBasicGeometryNode::setRendererClipList(const QSGClipNode*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setRendererClipList_1native_1const_1QSGClipNode_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID c0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setRendererClipList(const QSGClipNode*)", __this_nativeId)
        const QSGClipNode* __qt_c0 = QtJambiAPI::objectFromNativeId<QSGClipNode>(c0);
        __qt_this->setRendererClipList(__qt_c0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QSGBasicGeometryNode::setRendererMatrix(const QMatrix4x4*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGBasicGeometryNode_setRendererMatrix_1native_1const_1QMatrix4x4_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID m0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QSGBasicGeometryNode *__qt_this = QtJambiAPI::objectFromNativeId<QSGBasicGeometryNode>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGBasicGeometryNode::setRendererMatrix(const QMatrix4x4*)", __this_nativeId)
        const QMatrix4x4* __qt_m0 = QtJambiAPI::objectFromNativeId<QMatrix4x4>(m0);
        __qt_this->setRendererMatrix(__qt_m0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGBasicGeometryNode(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGBasicGeometryNode>("QSGBasicGeometryNode", "io/qt/quick/QSGBasicGeometryNode");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "isSubtreeBlocked", "()Z"),
        FunctionInfo(/* 1 */ "preprocess", "()V")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGBasicGeometryNode, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGBasicGeometryNode);
    registerSizeOfShell(typeId, sizeof(QSGBasicGeometryNode_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGNode, QSGBasicGeometryNode>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
